generate_config_file.py
=======================

`View code on Github <https://github.com/activist-org/i18n-check/blob/main/src/i18n_check/cli/generate_config_file.py>`_

.. automodule:: i18n_check.cli.generate_config_file
    :members:
    :private-members:
